import java.util.*;
/**
 * Bag implement represents multi sets (bags) of Sessions
 * 
 * @author Michael E. Caspersen, Jens Benendsen 
 * @version 20 April 2001<br>
 * Revision: 22 December 1998: Created
 * Revision: 26 April 2009: Gries
 */
class Bag {
    
    // The sessions in the bag - from 0 to l-1.
    private Session[] items;
    
    //The number of elements in the bag.
    private int l;
    
    /** Constructor: an empty bag capable of containing at most 100 elements.
      */
    public Bag () {
        items= new Session[100];
        l= 0;
    }
    
    /** = "the bag is empty". */
    public boolean isEmpty() {
        return l == 0;
    }
    
    /** = "s is in this bag". */
    public boolean member(Session s) {
        /** inv s is not one of the first i items of the bag */
        for (int i= 0; i < l; i= i+1) {
            if (items[i].equals(s))
                return true;
        }
        return false;
    }
    
    /** Put s in this bag.
        Precondition: no Session with the same number as s is in this bag. */
    public void insert (Session s) {
        items[l]= s;
        l= l+1;
    }
    
    /** = the session with session number k (null if session is not in this bag). */
    public Session lookup (int k) {
        // inv. Session with number k is not one the first i items.
        for (int i= 0; i < l; i= i+1) {
            if (items[i].getNr() == k)
                return items[i];
        }
        
        // Session with number k is not in the bag.
        return null;
    }
    
    /** Remove the session with session number k.
        Precondition: a session with number k is in the bag. */
    public void remove (int k) {
        int i;
        for (i= 0; items[i].getNr() != k; i++);
        
        items[i]= items[l-1];
        l--;
    }
    
    /** This private class implements an iterator through the sessions.
      * Its methods are specified in interface Iterator. */
    private class Ite implements Iterator {
        // position in the bag of next element to enumerate
        private int pos= 0;
        
        public boolean hasNext() {
            return pos < l;
        } 
        
        public Object next() throws NoSuchElementException {
            if (hasNext())
                return items[pos++];
            else
                throw new NoSuchElementException();
        }
        
        public void remove() throws UnsupportedOperationException {
            throw new UnsupportedOperationException();
        }
        
    }
    
    /** = an iterator that iterates through the sessions in the bag. */
    public Iterator iterator() {
        return new Ite();
    }
    
}