import java.util.*;
import java.text.*;
import java.io.*;
/**
 * class Showboat is the user interface to the showboat application.
 * Execute it using  Showboat.run();
 * 
 * @author Jens Bennedsen 
 * @version 20 April 2001
 * modified 20 April 2008 by mec
 * modified 26 April 20009 by Gries
 */

class Showboat {
    /** months of year. 1 is jan, etc. */
    private static final String[] monthStr= {"", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
        
    // Functions that the user can use
    private static Functions f= new Functions();
   
    /** Constructor: an instance of this class. Note that the constructor
      is private, so it cannot be instantiated outside this class.*/
    private Showboat() {}
    
    /** Opn a place for the user to type commands:
        'S' means start a session, 'E' means end a session,
        '.' means stop running and print a report.
     */
    public static void run() throws IOException {
        char command = '.';
        int sessionNr = 0;
        command= getChar();
        while (command != '.') {
            if (command == 's') {
                sessionNr= sessionNr + 1;
                f.beginSession(sessionNr);
            } else if (command == 'e') {
                showStatus();
                int nr= getInt();
                boolean ok= f.endSession(nr);
                if (ok) {
                     System.out.println("Session " + nr + " ended.");
                 } else {
                     System.out.println("Sorry, " + nr + " is not the number of a current session.");
                 }
            }
            command= getChar();
        }
        printDailyReport(f.doDailyReport());
    }
    
    /** Print a list of the current sessions. */
    private static void showStatus() {
        String statusStr= "";
        
        statusStr= f.getStatus();
        
        System.out.print("Active rentals: "); System.out.println(statusStr);
    }
    
    /** Print the daily report. */
    private static void printDailyReport(ReportInfo r) {
        Calendar today = new GregorianCalendar();
        int day= today.get(Calendar.DAY_OF_MONTH);
        int month= today.get(Calendar.MONTH) + 1;
        int year= today.get(Calendar.YEAR);
        String dateOut= day + " " + monthStr[month] + " " + year;
        
        int hour= today.get(Calendar.HOUR_OF_DAY);
        String hourStr= (hour < 10 ? "0" : "") + hour;
        
        int minute= today.get(Calendar.MINUTE);
        String minuteStr= (minute < 10 ? "0" : "") + minute;
        
        String timeOut = hourStr + ":" + minuteStr;
        
        System.out.println();
        System.out.println("*************************************");
        System.out.println("*      S H O W B O A T   Inc        *");
        System.out.println("*************************************");
        System.out.println("Daily Report    " + dateOut + "     " + timeOut);
        System.out.println("                                     ");
        System.out.print("Number of Sessions:                 ");
        System.out.println(r.getNrOfSessions());
        System.out.print("Average rental time:         ");
        System.out.println(r.getAvgTime());
        System.out.println("*************************************");
        System.out.println();
    }
    
    
    /* ******************************************* */
    /* **********  Basic I/O Functions  ********** */
    /* ******************************************* */
    
    /** = the character typed by the user. */
    private static char getChar() {
        char inputString []= new char[2];
        Reader in= new InputStreamReader(System.in);
        
        System.out.print("(S, E, .)? ");
        try {
            in.read(inputString);
        } catch (java.io.IOException e) { }
        return inputString[0];
    }
    
    /** Prompt the user for a rental number --and keep prompting until
        one is typed. Return the rental number. */
    private static int getInt() throws IOException {
        char inputString []= new char[400];
        Reader in= new InputStreamReader(System.in);
        System.out.print("(Enter rental number)? ");
        int size= in.read(inputString);
        
        // invariant: inputString[0..size-1] contains the last input line read; previous
        // lines did not contain a recognizable integer.
        while (true) {
            try {
                return Integer.valueOf(new String(inputString, 0, size).trim()).intValue();
            }
            catch (NumberFormatException e) {
                System.out.println(
                                   "Input is not an integer. Try again: enter a rental number:");
                size= in.read(inputString);
            }
        }
    }
}